==> parodia_admin-1.0.2.tar.gz: lib/core/repository/productPriceGroup.repository.dart <==
// GET
// /api/v1/dashboard/products/prices/groups/{id}

// PUT
// /api/v1/dashboard/products/prices/groups/{id}

// DELETE
// /api/v1/dashboard/products/prices/groups/{id}

// GET
// /api/v1/dashboard/products/prices/groups

// POST
// /api/v1/dashboard/products/prices/groups

// POST
// /api/v1/dashboard/products/prices/groups/{id}/recover

import 'package:parodia_admin/core/dto/product_price_group.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class ProductPriceGroupRepository {
  ParodiaHTTP? _http;

  ProductPriceGroupRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ProductPriceGroupDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/products/prices/groups',
      param: id,
    );

    return ResponseItemDTO<ProductPriceGroupDTO>(
      response: response,
      fromJson: ProductPriceGroupDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ProductPriceGroupDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/products/prices/groups',
      query: query,
    );

    return ResponseListDTO<ProductPriceGroupDTO>(
      response: response,
      fromJson: ProductPriceGroupDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({PriceGroupBody? priceGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/products/prices/groups',
      data: priceGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, PriceGroupBody? priceGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/products/prices/groups',
      param: id,
      data: priceGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/products/prices/groups',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/products/prices/groups/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/productPriceGroup.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/products/prices/groups/{id}

// PUT
// /api/v1/dashboard/dashboard/products/prices/groups/{id}

// DELETE
// /api/v1/dashboard/dashboard/products/prices/groups/{id}

// GET
// /api/v1/dashboard/dashboard/products/prices/groups

// POST
// /api/v1/dashboard/dashboard/products/prices/groups

// POST
// /api/v1/dashboard/dashboard/products/prices/groups/{id}/recover

import 'package:parodia_admin/core/dto/product_price_group.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class ProductPriceGroupRepository {
  ParodiaHTTP? _http;

  ProductPriceGroupRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ProductPriceGroupDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/products/prices/groups',
      param: id,
    );

    return ResponseItemDTO<ProductPriceGroupDTO>(
      response: response,
      fromJson: ProductPriceGroupDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ProductPriceGroupDTO>> getAll({StoreQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/products/prices/groups',
      query: query,
    );

    return ResponseListDTO<ProductPriceGroupDTO>(
      response: response,
      fromJson: ProductPriceGroupDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({PriceGroupBody? priceGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/products/prices/groups',
      data: priceGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, PriceGroupBody? priceGroup}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/products/prices/groups',
      param: id,
      data: priceGroup,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/products/prices/groups',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/products/prices/groups/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
